@@ -3,7 +3,7 @@ package HTTP::Response;
 use strict;
 use warnings;
 
-our $VERSION = '6.19'; # TRIAL
+our $VERSION = '6.20'; # TRIAL
 
 use base 'HTTP::Message';
 
@@ -143,7 +143,11 @@ sub filename {
                     require Encode;
                     require Encode::Locale;
                     $fs_encfile = URI::Escape::uri_unescape($fs_encfile);
-                    Encode::from_to( $fs_encfile, $fs_charset, "locale_fs" );
+                    # try hard to make a usable file name,
+                    # see <https://dwheeler.com/encodef/>
+                    Encode::from_to( $fs_encfile, $fs_charset, "locale_fs",
+                        sub { URI::Escape::uri_escape_utf8(chr shift) }
+                    );
 
                     $file = $fs_encfile;
                 }
@@ -376,7 +380,7 @@ HTTP::Response - HTTP style response message
 
 =head1 VERSION
 
-version 6.19
+version 6.20
 
 =head1 SYNOPSIS
 
